@@ -49,8 +49,9 @@ Clayton.Markov2.MLE = function(Y, k = 3, D = 1, plot = TRUE, GOF=FALSE){
   UCL = mu.hat+k*sigma.hat
   LCL = mu.hat-k*sigma.hat
 
-  CL = c(Upper = UCL, Lower = LCL)
 
+  CL = c(Center = mu.hat, Lower = LCL, Upper = UCL)
+  
   Gradient = res$gradient
   Hessian = -res$hessian
 
@@ -104,7 +105,7 @@ Clayton.Markov2.MLE = function(Y, k = 3, D = 1, plot = TRUE, GOF=FALSE){
 
   ##output
   return(list( mu=result.mu, sigma = result.sigma, alpha = result.alpha,
-               CL = CL, out_of_control = OC,
-               Gradient = Gradient, Hessian = Hessian, Mineigenvalue_Hessian=min(eigen(Hessian)$value),
+               Control_Limit = CL, out_of_control = OC,
+               Gradient = Gradient, Hessian = Hessian, Eigenvalue_Hessian=eigen(Hessian)$value,
                CM.test=CM.test, KS.test=KS.test,log_likelihood = -logL(res$estimate)))
 }
